@@ -5,7 +5,8 @@ from navability.entities.client import Client
 from navability.entities.navabilityclient import MutationOptions, NavAbilityClient
 
 
-def solveSession(navAbilityClient: NavAbilityClient, client: Client):
-    return navAbilityClient.mutate(
+async def solveSession(navAbilityClient: NavAbilityClient, client: Client):
+    result = await navAbilityClient.mutate(
         MutationOptions(gql(GQL_SOLVESESSION), {"client": client.dump()})
-    )["solveSession"]
+    )
+    return result["solveSession"]
